pub enum Record {
Contact(ContactRecord),
GroupV1(GroupV1Record),
GroupV2(GroupV2Record),
Account(AccountRecord),
StoryDistributionList(StoryDistributionListRecord),
CallLink(CallLinkRecord),
ChatFolder(ChatFolderRecord),
NotificationProfile(NotificationProfile),
}Variants
Contact(ContactRecord)
GroupV1(GroupV1Record)
GroupV2(GroupV2Record)
Account(AccountRecord)
StoryDistributionList(StoryDistributionListRecord)
CallLink(CallLinkRecord)
ChatFolder(ChatFolderRecord)
NotificationProfile(NotificationProfile)
Implementations
Sourceimpl Record
impl Record
Sourcepub fn merge(
field: &mut Option<Record>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Record>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.